import axios from 'axios';

export default {
  namespaced: true,
  state: {
    propertySearch: {
      userID: 0,
      keyword: '',
      salesType: 'Sale',
      propertyUsageType: 'All',
      propertyType: 'All',
      province: 'All',
      city: 'All',
      suburb: 'All',
    },
    properties: [],
    latestProperties: [],
  },
  mutations: {
    updateSearch(state, propertySearch) {
      state.properties = [];
      state.properties = propertySearch;
    },
    setLatestProperties(state, properties) {
      state.latestProperties = properties;
    },
    setPropertySearch(state, search) {
      state.propertySearch = search;
    },
    onClearFilter(state, filter) {
      state.propertySearch[filter] = 'All';
    },
  },
  getters: {},
  actions: {
    clearFilter({ commit }, filter) {
      commit('onClearFilter', filter);
    },
    getPropertySearchObject({ commit }) {
      const search = {
        userID: 0,
        keyword: '',
        salesType: 'Sale',
        propertyUsageType: 'All',
        propertyType: 'All',
        province: 'All',
        city: 'All',
        suburb: 'All',
      };
      commit('setPropertySearch', search);
    },
    searchProperties({ commit }, item) {
      axios
        .post('/api/Property/Search', item)
        .then(result => commit('updateSearch', result.data))
        .catch(console.error);
    },
    searchLatestProperties({ commit }) {
      axios
        .get('/api/property/latestProperties')
        .then(response => commit('setLatestProperties', response.data))
        .catch(console.error);
    },
  },
};
